Module: RConfig::Exceptions
- Included in:
- RConfig
- Defined in:
- lib/rconfig/exceptions.rb
Instance Method Summary collapse
-
#raise_load_path_error ⇒ Object
Raised when no valid load paths are available.
-
#raise_logger_error ⇒ Object
Raised if logging is enabled, but no logger is specified}.
Instance Method Details
#raise_load_path_error ⇒ Object
Raised when no valid load paths are available.
16 17 18 |
# File 'lib/rconfig/exceptions.rb', line 16 def raise_load_path_error raise InvalidLoadPathError, "No load paths were provided, and none of the default paths were found." end |
#raise_logger_error ⇒ Object
Raised if logging is enabled, but no logger is specified}.
21 22 23 |
# File 'lib/rconfig/exceptions.rb', line 21 def raise_logger_error raise ConfigError, "No logger was specified, and a defualt logger was not found. Set logger to `false` to disable logging." end |